@@ -50,17 +50,10 @@ class Listener(object):
 
     self._heartbeat_thread = threading.Thread(
       target=self._send_heartbeat,
-      #daemon=True,
       name='HeartbeatBackgroundThread')
 
   def __enter__(self):
-    # connect to socket
-    self._sock = self._init_sock_()
-    self._sock_bounded = True
-    self._decrypter = Decrypter()
-
-    # start heartbeat thread
-    self._heartbeat_thread.start()
+    self.start()
     return self
 
   def __exit__(self, exc_type, exc_val, exc_tb):
@@ -72,6 +65,16 @@ class Listener(object):
   def __del__(self):
     self.close()
 
+  def start(self):
+    # connect to socket
+    self._sock = self._init_sock_()
+    self._sock_bounded = True
+    self._decrypter = Decrypter()
+
+    # start heartbeat thread
+    self._heartbeat_thread.start()
+    return self
+
   def close(self):
     """
     Kills the background process which sends heartbeats to the PlayStation. If this is not called, your program will not
